==> zio-aws-route53_2.13-7.28.29.7-sources.jar: zio/aws/route53/model/ListHealthChecksRequest.scala <==
package zio.aws.route53.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.route53.model.primitives.{PageMaxItems, PageMarker}
import scala.jdk.CollectionConverters._
final case class ListHealthChecksRequest(
    marker: Optional[PageMarker] = Optional.Absent,
    maxItems: Optional[PageMaxItems] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53.model.ListHealthChecksRequest = {
    import ListHealthChecksRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53.model.ListHealthChecksRequest
      .builder()
      .optionallyWith(
        marker.map(value => PageMarker.unwrap(value): java.lang.String)
      )(_.marker)
      .optionallyWith(
        maxItems.map(value => PageMaxItems.unwrap(value): java.lang.String)
      )(_.maxItems)
      .build()
  }
  def asReadOnly: zio.aws.route53.model.ListHealthChecksRequest.ReadOnly =
    zio.aws.route53.model.ListHealthChecksRequest.wrap(buildAwsValue())
}
object ListHealthChecksRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53.model.ListHealthChecksRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.route53.model.ListHealthChecksRequest =
      zio.aws.route53.model.ListHealthChecksRequest(
        marker.map(value => value),
        maxItems.map(value => value)
      )
    def marker: Optional[PageMarker]
    def maxItems: Optional[PageMaxItems]
    def getMarker: ZIO[Any, AwsError, PageMarker] =
      AwsError.unwrapOptionField("marker", marker)
    def getMaxItems: ZIO[Any, AwsError, PageMaxItems] =
      AwsError.unwrapOptionField("maxItems", maxItems)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53.model.ListHealthChecksRequest
  ) extends zio.aws.route53.model.ListHealthChecksRequest.ReadOnly {
    override val marker: Optional[PageMarker] = zio.aws.core.internal
      .optionalFromNullable(impl.marker())
      .map(value => zio.aws.route53.model.primitives.PageMarker(value))
    override val maxItems: Optional[PageMaxItems] = zio.aws.core.internal
      .optionalFromNullable(impl.maxItems())
      .map(value => zio.aws.route53.model.primitives.PageMaxItems(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53.model.ListHealthChecksRequest
  ): zio.aws.route53.model.ListHealthChecksRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-route53_3-5.17.116.1-sources.jar: zio/aws/route53/model/ListHealthChecksRequest.scala <==
package zio.aws.route53.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.route53.model.primitives.{PageMaxItems, PageMarker}
import scala.jdk.CollectionConverters.*
final case class ListHealthChecksRequest(
    marker: Option[PageMarker] = None,
    maxItems: Option[PageMaxItems] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53.model.ListHealthChecksRequest = {
    import ListHealthChecksRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53.model.ListHealthChecksRequest
      .builder()
      .optionallyWith(
        marker.map(value => PageMarker.unwrap(value): java.lang.String)
      )(_.marker)
      .optionallyWith(
        maxItems.map(value => PageMaxItems.unwrap(value): java.lang.String)
      )(_.maxItems)
      .build()
  }
  def asReadOnly: zio.aws.route53.model.ListHealthChecksRequest.ReadOnly =
    zio.aws.route53.model.ListHealthChecksRequest.wrap(buildAwsValue())
}
object ListHealthChecksRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53.model.ListHealthChecksRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.route53.model.ListHealthChecksRequest =
      zio.aws.route53.model.ListHealthChecksRequest(
        marker.map(value => value),
        maxItems.map(value => value)
      )
    def marker: Option[PageMarker]
    def maxItems: Option[PageMaxItems]
    def getMarker: ZIO[Any, AwsError, PageMarker] =
      AwsError.unwrapOptionField("marker", marker)
    def getMaxItems: ZIO[Any, AwsError, PageMaxItems] =
      AwsError.unwrapOptionField("maxItems", maxItems)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53.model.ListHealthChecksRequest
  ) extends zio.aws.route53.model.ListHealthChecksRequest.ReadOnly {
    override val marker: Option[PageMarker] = scala
      .Option(impl.marker())
      .map(value => zio.aws.route53.model.primitives.PageMarker(value))
    override val maxItems: Option[PageMaxItems] = scala
      .Option(impl.maxItems())
      .map(value => zio.aws.route53.model.primitives.PageMaxItems(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53.model.ListHealthChecksRequest
  ): zio.aws.route53.model.ListHealthChecksRequest.ReadOnly = new Wrapper(impl)
}
